@@ -17,35 +17,28 @@
 #ifndef _GLOBUS_CALLOUT_H_
 #define _GLOBUS_CALLOUT_H_
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
- * @file globus_callout.c
- * Globus Callout Infrastructure
+ * @file globus_callout.h
+ * @brief Globus Callout Infrastructure
  * @author Sam Meder
- *
- * $RCSfile: globus_callout.h,v $
- * $Revision: 1.9.34.1 $
- * $Date: 2012/02/13 14:31:05 $
  */
-#endif
 
-#ifndef EXTERN_C_BEGIN
-#    ifdef __cplusplus
-#        define EXTERN_C_BEGIN extern "C" {
-#        define EXTERN_C_END }
-#    else
-#        define EXTERN_C_BEGIN
-#        define EXTERN_C_END
-#    endif
-#endif
 
 #include "globus_common.h"
 #include "globus_callout_constants.h"
 
-EXTERN_C_BEGIN
+#ifdef __cplusplus
+extern "C" {
+#endif
 
+#ifndef GLOBUS_GLOBAL_DOCUMENT_SET
 /**
  * @mainpage Globus Callout API
+ * @copydoc globus_callout
+ */
+#endif
+/**
+ * @defgroup globus_callout Globus Callout API
  *
  * This API is intended to ease integration of configurable callouts into the
  * Globus Toolkit and to provide a platform independent way of dealing with
@@ -54,35 +47,42 @@ EXTERN_C_BEGIN
  *
  * - It provides a function for reading callout configuration files. Files are
  *   assumed to have the following format:
- *    - Anything after a '#' is assumed to be a comment
+ *    - Anything after a <tt>#</tt> is assumed to be a comment
  *    - Blanks lines are ignored
  *    - Lines specifying callouts have the format
- *      abstract type           library         symbol
- *      where "abstract type" denotes the type of callout,
- *      e.g. globus_gram_jobmanager_authz, "library" denotes the library the
- *      callout can be found in and "symbol" denotes the function name of the
- *      callout.
+ @verbatim
+       abstract type           library         symbol
+ @endverbatim
+ *      where <i>abstract type</i> denotes the type of callout,
+ *      e.g. globus_gram_jobmanager_authz, <i>library</i> denotes the library
+ *      the callout can be found in and <i>symbol</i> denotes the function name
+ *      of the callout.
  * - It provides a API function for registering callouts
  * - All callouts are assumed to have the function signature
  *   globus_result_t callout_func(va_list ap)
- * - It provides a function for calling a callout given a abstract type. If
+ * - It provides a function for calling a callout given an abstract type. If
  *   multiple callouts are defined for the same abstract type then all callouts
  *   for the abstract type will be called. Implementers should not rely on any
  *   correlation between the order of configuration and the order of invocation
  *   of callouts of the same abstract type.
  *
  * Any program that uses Globus Callout functions must include
- * "globus_callout.h".  
+ * the globus_callout.h header
  *
- * @htmlonly
- * <a href="main.html" target="_top">View documentation without frames</a><br>
- * <a href="index.html" target="_top">View documentation with frames</a><br>
- * @endhtmlonly
+ * Function Categories
+ * - @ref globus_callout_activation
+ * - @ref globus_callout_handle
+ * - @ref globus_callout_config 
+ * - @ref globus_callout_call 
+ * - @ref globus_callout_constants
  */
 
 /** 
  * @defgroup globus_callout_activation Activation
+ * @ingroup globus_callout
+ * @brief Callback API Activation
  *
+ * @details
  * Globus Callout API uses standard Globus module activation and
  * deactivation.  Before any Globus Callout API functions are called, the
  * following function must be called:
@@ -137,9 +137,11 @@ typedef globus_result_t (*globus_callout_function_t)(
 
 /**
  * @defgroup globus_callout_handle Callout Handle Operations
+ * @ingroup globus_callout
  *
- * Initialize and Destory a Globus Callout Handle structure.
+ * @brief Manage a Globus Callout Handle structure
  *
+ * @details
  * This section defines operations for initializing and destroying Globus
  * Callout Handle structure.
  */
@@ -153,9 +155,11 @@ globus_callout_handle_destroy(
 
 /**
  * @defgroup globus_callout_config Callout Configuration
+ * @ingroup globus_callout
  *
- * Functions for registering callouts.
+ * @brief Register callouts
  *
+ * @details
  * This section defines operations for registering callouts. Callouts may be
  * registered either through a configuration file or through calls to
  * globus_callout_register. 
@@ -174,9 +178,11 @@ globus_callout_register(
 
 /**
  * @defgroup globus_callout_call Callout Invocation
+ * @ingroup globus_callout
  *
- * Functions for invoking callouts.
+ * @brief Invoke callouts
  *
+ * @details
  * This section defines a operation for invoking callouts by their abstract
  * type. 
  */
@@ -187,6 +193,8 @@ globus_callout_call_type(
     ...);
 
 
-EXTERN_C_END
+#ifdef __cplusplus
+}
+#endif
 
 #endif
